.. fem documentation master file, created by
   sphinx-quickstart on Mon May 21 15:12:35 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Examples
--------

.. toctree::
    :maxdepth: 2

    examples

Module index
------------

.. toctree::
   :maxdepth: 1

   _source/modules
